==> haskell-storablevector-0.2.13-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storablevector
version:              0.2.13
visibility:           public
id:                   storablevector-0.2.13-LcUudNgJth61cHjCB6hOoS
key:                  storablevector-0.2.13-LcUudNgJth61cHjCB6hOoS
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  c4eaf0496352bed44d2bd5b98a47ff65
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-8.8.1/site-local/storablevector-0.2.13
library-dirs:         /usr/lib/ghc-8.8.1/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/storablevector-0.2.13
hs-libraries:         HSstorablevector-0.2.13-LcUudNgJth61cHjCB6hOoS
depends:
    QuickCheck-2.13.2-1s2yEbt3iMvAcG0hiAunO4 base-4.13.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-IHTqTxiWvnZCRHjUsInMbj
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM transformers-0.5.6.2
    unsafe-0.0-BWEGoAYViJhEGPiaFlqnP7
    utility-ht-0.0.14-91eaeeiLFdf4qEslKceik0

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-storablevector-0.2.13-30-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-storablevector.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 storablevector
version:              0.2.13
visibility:           public
id:                   storablevector-0.2.13-FBZfZqAs3PY4ZZrbBcPx9v
key:                  storablevector-0.2.13-FBZfZqAs3PY4ZZrbBcPx9v
license:              BSD-3-Clause
maintainer:           Henning Thielemann <storablevector@henning-thielemann.de>
author:
    Spencer Janssen <sjanssen@cse.unl.edu>, Henning Thielemann <storablevector@henning-thielemann.de>

stability:            Experimental
homepage:             http://www.haskell.org/haskellwiki/Storable_Vector
synopsis:
    Fast, packed, strict storable arrays with a list interface like ByteString

description:
    Fast, packed, strict storable arrays
    with a list interface,
    a chunky lazy list interface with variable chunk size
    and an interface for write access via the @ST@ monad.
    This is much like @bytestring@ and @binary@
    but can be used for every '\''Foreign.Storable.Storable'\'' type.
    See also package
    <http://hackage.haskell.org/package/vector>
    with a similar intention.

    We do not provide advanced fusion optimization,
    since especially for lazy vectors
    this would either be incorrect or not applicable.
    However we provide fusion with lazy lists in the package
    <http://hackage.haskell.org/package/storablevector-streamfusion>.

category:             Data
abi:                  bc1a1e6bbd120475f1fe1f77144ad6a2
exposed:              True
exposed-modules:
    Data.StorableVector Data.StorableVector.Base
    Data.StorableVector.Lazy Data.StorableVector.Lazy.Builder
    Data.StorableVector.Lazy.Pattern Data.StorableVector.Lazy.Pointer
    Data.StorableVector.Lazy.Typed Data.StorableVector.Pointer
    Data.StorableVector.ST.Lazy Data.StorableVector.ST.Strict

hidden-modules:
    Data.StorableVector.Memory Data.StorableVector.ST.Private
    Data.StorableVector.Lazy.PointerPrivate
    Data.StorableVector.Lazy.PointerPrivateIndex
    Data.StorableVector.Cursor

import-dirs:          /usr/lib/ghc-8.8.1/site-local/storablevector-0.2.13
library-dirs:         /usr/lib/ghc-8.8.1/site-local/storablevector-0.2.13
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.1/storablevector-0.2.13
hs-libraries:         HSstorablevector-0.2.13-FBZfZqAs3PY4ZZrbBcPx9v
depends:
    QuickCheck-2.13.2-7Zr43MCMpvVZ9AxOmzbZ0 base-4.13.0.0
    deepseq-1.4.4.0 non-negative-0.1.2-J4tl3B0yogxAJMbr5XwZ7l
    syb-0.7.1-HZot41yU46FEB2GjLEhNpM transformers-0.5.6.2
    unsafe-0.0-BWEGoAYViJhEGPiaFlqnP7
    utility-ht-0.0.14-91eaeeiLFdf4qEslKceik0

haddock-interfaces:
    /usr/share/doc/haskell-storablevector/html/storablevector.haddock

haddock-html:         /usr/share/doc/haskell-storablevector/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
